@@ -54,7 +54,7 @@ Common Patterns:
 
     @app.post("/items")
     async def create_item(request, response):
-        item = Item(**await request.json())
+        item = Item(**await request.json)
         return response.json(item)
 
 3. Custom Middleware:
@@ -167,6 +167,7 @@ def get_application(
     ] = None,
     lifespan: Optional[Callable[["NexiosApp"], AsyncContextManager[bool]]] = None,
     routes: Optional[list[Router]] = None,
+    dependencies: Optional[list[Depend]] = None,
 ) -> NexiosApp:
     """
     Initializes and returns a `Nexios` application instance, serving as the core entry point for
@@ -204,6 +205,8 @@ def get_application(
         version=version,
         description=description,
         lifespan=lifespan,
+        routes=routes,
+        dependencies=dependencies,
     )
 
     return app
