@@ -122,6 +122,9 @@ class BaseUser:
             str: The unique identifier of the user.
         """
         raise NotImplementedError()
+    def has_permission(self, permission :str):
+        """checks if the request user has the provided permission"""
+
 
 
 class SimpleUser(BaseUser):
@@ -132,7 +135,9 @@ class SimpleUser(BaseUser):
     """
 
     def __init__(
-        self, username: Annotated[str, Doc("The username of the authenticated user.")]
+        self, 
+        username: Annotated[str, Doc("The username of the authenticated user.")],
+        permissions = Annotated[str, Doc("Array of user User Permissions")]
     ) -> None:
         """
         Initializes a simple authenticated user.
@@ -141,6 +146,7 @@ class SimpleUser(BaseUser):
             username (str): The username of the user.
         """
         self.username = username
+        self.permissions = permissions
 
     @property
     def is_authenticated(
@@ -167,6 +173,8 @@ class SimpleUser(BaseUser):
             str: The username of the authenticated user.
         """
         return self.username
+    def has_permission(self, permission: str):
+        return permission in self.permissions
 
 
 class UnauthenticatedUser(BaseUser):
