@@ -143,8 +143,8 @@ class Routes(BaseRoute):
         security: Optional[List[Dict[str, List[str]]]] = None,
         operation_id: Optional[str] = None,
         deprecated: bool = False,
-        parameters: List[Parameter] = [],
-        middleware: List[Any] = [],
+        parameters: Optional[List[Parameter]] = None,
+        middleware: Optional[List[Any]] = None,
         exclude_from_schema: bool = False,
         **kwargs: Dict[str, Any],
     ):
@@ -180,7 +180,9 @@ class Routes(BaseRoute):
         self.pattern: Pattern[str] = self.route_info.pattern
         self.param_names = self.route_info.param_names
         self.route_type = self.route_info.route_type
-        self.middleware: typing.List[MiddlewareType] = list(middleware)
+        self.middleware: typing.List[MiddlewareType] = (
+            list(middleware) if middleware else []
+        )
         self.summary = summary
         self.description = description
         self.responses = responses
@@ -190,7 +192,7 @@ class Routes(BaseRoute):
         self.security = security
         self.operation_id = operation_id
         self.deprecated = deprecated
-        self.parameters = parameters
+        self.parameters = parameters or []
         self.exclude_from_schema = exclude_from_schema
 
     def match(self, path: str, method: str) -> typing.Tuple[Any, Any, Any]:
@@ -211,7 +213,7 @@ class Routes(BaseRoute):
                 matched_params[key] = self.route_info.convertor[  # type: ignore
                     key
                 ].convert(value)
-            is_method_allowed = method.lower() in [m.lower() for m in self.methods]
+            is_method_allowed = method.lower() in (m.lower() for m in self.methods)
             return match, matched_params, is_method_allowed
         return None, None, False
 
@@ -262,7 +264,7 @@ class Routes(BaseRoute):
         Returns:
             Response: The processed HTTP response object.
         """
-
+        
         async def apply_middleware(app: ASGIApp) -> ASGIApp:
             middleware: typing.List[Middleware] = []
             for mdw in self.middleware:
@@ -293,6 +295,7 @@ class Router(BaseRouter):
         tags: Optional[List[str]] = None,
         exclude_from_schema: bool = False,
         name: Optional[str] = None,
+        dependencies: Optional[list] = None,
     ):
         self.prefix = prefix or ""
         self.prefix.rstrip("/")
@@ -304,6 +307,7 @@ class Router(BaseRouter):
         self.exclude_from_schema = exclude_from_schema
         self.name = name
         self.event = AsyncEventEmitter()
+        self.dependencies = dependencies or []
 
         if self.prefix and not self.prefix.startswith("/"):
             warnings.warn("Router prefix should start with '/'")
@@ -534,7 +538,6 @@ class Router(BaseRouter):
 
         route.tags = self.tags + route.tags if route.tags else self.tags
         # original_handler = route.handler
-
         if self.exclude_from_schema:
             route.exclude_from_schema = True
         original_handler = route.handler
@@ -557,7 +560,7 @@ class Router(BaseRouter):
 
             return await original_handler(*handler_args, **handler_kwargs)
 
-        route.handler = inject_dependencies(wrapped_handler)
+        route.handler = wrapped_handler
 
         self.routes.append(route)
 
@@ -803,7 +806,7 @@ class Router(BaseRouter):
                 Async handler function for POST requests.
                 Example:
                 async def create_user(request, response):
-                    user_data = request.json()
+                    user_data = request.json
                     return response.json(user_data, status=201)
             """
             ),
@@ -941,7 +944,7 @@ class Router(BaseRouter):
             1. Simple POST endpoint:
             @router.post("/messages")
             async def create_message(request, response):
-                message = await Message.create(**request.json())
+                message = await Message.create(**request.json)
                 return response.json(message, status=201)
 
             2. POST with request validation:
@@ -1337,7 +1340,7 @@ class Router(BaseRouter):
             @router.put("/users/{id}")
             async def update_user(request, response):
                 user_id = request.path_params['id']
-                await User.update(user_id, **request.json())
+                await User.update(user_id, **request.json)
                 return response.json({"status": "updated"})
 
             2. PUT with full resource replacement:
@@ -1539,7 +1542,7 @@ class Router(BaseRouter):
             @router.patch("/users/{id}")
             async def update_user(request, response):
                 user_id = request.path_params['id']
-                await User.partial_update(user_id, **request.json())
+                await User.partial_update(user_id, **request.json)
                 return response.json({"status": "updated"})
 
             2. PATCH with JSON Merge Patch:
@@ -1559,7 +1562,7 @@ class Router(BaseRouter):
             @router.patch("/profile")
             async def update_profile(request, response):
                 allowed_fields = {'bio', 'avatar_url'}
-                updates = {k: v for k, v in request.json().items()
+                updates = {k: v for k, v in request.json.items()
                         if k in allowed_fields}
                 await Profile.update(request.user.id, **updates)
                 return response.json(updates)
