@@ -1,7 +1,10 @@
 from __future__ import annotations
+
 import typing
+from typing import Any, Dict, ItemsView, Iterator, KeysView, Sequence, ValuesView
 from urllib.parse import SplitResult, parse_qsl, urlencode, urlsplit
-from nexios._utils.cuncurrency import run_in_threadpool
+
+from nexios.utils.concurrency import run_in_threadpool
 
 Scope = typing.MutableMapping[str, typing.Any]
 Message = typing.MutableMapping[str, typing.Any]
@@ -9,13 +12,13 @@ Message = typing.MutableMapping[str, typing.Any]
 Receive = typing.Callable[[], typing.Awaitable[Message]]
 Send = typing.Callable[[Message], typing.Awaitable[None]]
 
+
 class Address(typing.NamedTuple):
     host: str
     port: int
 
 
 _KeyType = typing.TypeVar("_KeyType")
-# Mapping keys are invariant but their values are covariant since
 # you can only read them
 # that is, you can't do `Mapping[str, Animal]()["fido"] = Dog()`
 _CovariantValueType = typing.TypeVar("_CovariantValueType", covariant=True)
@@ -25,7 +28,7 @@ class URL:
     def __init__(
         self,
         url: str = "",
-        scope :typing.Optional[Scope] = None,
+        scope: typing.Optional[Scope] = None,
         **components: typing.Any,
     ) -> None:
         if scope is not None:
@@ -107,13 +110,15 @@ class URL:
     @property
     def is_secure(self) -> bool:
         return self.scheme in ("https", "wss")
+
     @property
     def params(self):
         return
 
     @params.setter
-    def params(self,value :str):
+    def params(self, value: str):
         return value
+
     def replace(self, **kwargs: typing.Any) -> "URL":
         if (
             "username" in kwargs
@@ -230,6 +235,7 @@ class Secret:
     def __bool__(self) -> bool:
         return bool(self._value)
 
+
 class ImmutableMultiDict(typing.Mapping[_KeyType, _CovariantValueType]):
     _dict: typing.Dict[_KeyType, _CovariantValueType]
 
@@ -320,7 +326,7 @@ class MultiDict(ImmutableMultiDict[typing.Any, typing.Any]):
         self._list = [(k, v) for k, v in self._list if k != key]
         return self._dict.pop(key, default)
 
-    def popitem(self) -> typing.Tuple[typing.Any,typing.Any]:
+    def popitem(self) -> typing.Tuple[typing.Any, typing.Any]:
         key, value = self._dict.popitem()
         self._list = [(k, v) for k, v in self._list if k != key]
         return key, value
@@ -357,7 +363,7 @@ class MultiDict(ImmutableMultiDict[typing.Any, typing.Any]):
         self,
         *args: typing.Union[
             "MultiDict",
-            typing.Mapping[str,typing.Any],
+            typing.Mapping[str, typing.Any],
             typing.List[typing.Tuple[typing.Any, typing.Any]],
         ],
         **kwargs: typing.Any,
@@ -377,7 +383,7 @@ class QueryParams(ImmutableMultiDict[str, str]):
         self,
         *args: typing.Union[
             "ImmutableMultiDict[str,typing.Any]",
-            typing.Mapping[str,typing.Any],
+            typing.Mapping[str, typing.Any],
             typing.List[typing.Tuple[typing.Any, typing.Any]],
             str,
             bytes,
@@ -407,15 +413,10 @@ class QueryParams(ImmutableMultiDict[str, str]):
         query_string = str(self)
         return f"{class_name}({query_string!r})"
 
-    def __call__(self, *args: Any, **kwds: Any) -> Dict[str,Any]:
+    def __call__(self, *args: Any, **kwds: Any) -> Dict[str, Any]:
         return self._dict
 
 
-
-
-
-
-
 class Headers(typing.Mapping[str, str]):
     """
     An immutable, case-insensitive multidict.
@@ -431,17 +432,31 @@ class Headers(typing.Mapping[str, str]):
         if headers is not None:
             assert raw is None, 'Cannot set both "headers" and "raw".'
             assert scope is None, 'Cannot set both "headers" and "scope".'
-            self._list = [
-                (key.lower().encode("latin-1"), value.encode("latin-1"))
-                for key, value in headers.items()
-            ]
+            if isinstance(headers, typing.Mapping):  # type: ignore
+                self._list = [
+                    (key.lower().encode("latin-1"), value.encode("latin-1"))
+                    for key, value in headers.items()
+                ]
+            else:
+                # Assume it's a list of (bytes, bytes) tuples or something convertible
+                self._list = [
+                    (
+                        (
+                            k.lower()
+                            if isinstance(k, bytes)
+                            else k.lower().encode("latin-1")
+                        ),
+                        v if isinstance(v, bytes) else v.encode("latin-1"),
+                    )
+                    for k, v in headers
+                ]
         elif raw is not None:
             assert scope is None, 'Cannot set both "raw" and "scope".'
             self._list = raw
         elif scope is not None:
             # scope["headers"] isn't necessarily a list
             # it might be a tuple or other iterable
-            self._list = scope["headers"] = list(scope["headers"])
+            self._list = list(scope["headers"])
 
     @property
     def raw(self) -> typing.List[typing.Tuple[bytes, bytes]]:
@@ -459,7 +474,6 @@ class Headers(typing.Mapping[str, str]):
             for key, value in self._list
         ]
 
-
     def getlist(self, key: str) -> typing.List[str]:
         get_header_key = key.lower().encode("latin-1")
         return [
@@ -471,7 +485,7 @@ class Headers(typing.Mapping[str, str]):
     def mutablecopy(self) -> "MutableHeaders":
         return MutableHeaders(raw=self._list[:])
 
-    def __getitem__(self, key: str): #type: ignore[override]
+    def __getitem__(self, key: str):  # type: ignore[override]
         get_header_key = key.lower().encode("latin-1")
         for header_key, header_value in self._list:
             if header_key == get_header_key:
@@ -504,7 +518,6 @@ class Headers(typing.Mapping[str, str]):
         return f"{class_name}(raw={self.raw!r})"
 
 
-
 class MutableHeaders(Headers):
     def __setitem__(self, key: str, value: str) -> None:
         """
@@ -543,13 +556,13 @@ class MutableHeaders(Headers):
             del self._list[idx]
 
     def __ior__(self, other: typing.Mapping[str, str]) -> "MutableHeaders":
-        if not isinstance(other, typing.Mapping): #type: ignore
+        if not isinstance(other, typing.Mapping):  # type: ignore
             raise TypeError(f"Expected a mapping but got {other.__class__.__name__}")
         self.update(other)
         return self
 
     def __or__(self, other: typing.Mapping[str, str]) -> "MutableHeaders":
-        if not isinstance(other, typing.Mapping): #type: ignore
+        if not isinstance(other, typing.Mapping):  # type: ignore
             raise TypeError(f"Expected a mapping but got {other.__class__.__name__}")
         new = self.mutablecopy()
         new.update(other)
@@ -613,21 +626,12 @@ class State:
         try:
             return self._state[key]
         except KeyError:
-           return None
+            return None
 
     def __delattr__(self, key: typing.Any) -> None:
         del self._state[key]
-        
-    
 
 
-
-
-
-
-
-from typing import Any, Dict, Iterator, ItemsView, KeysView, ValuesView
-
 class RouteParam:
     def __init__(self, data: Dict[str, Any]) -> None:
         """Initialize the RouteParam with a dictionary."""
@@ -676,18 +680,18 @@ class RouteParam:
         """Return the number of items in the dictionary."""
         return len(self.data)
 
-    def __call__(self, *args: Any, **kwds: Any) ->  Dict[str, Any]:
+    def __call__(self, *args: Any, **kwds: Any) -> Dict[str, Any]:
         return self.data
-    
-    def get(self, key :str):
-        return self.data.get(key)
-    
-    def __dict__(self) -> Dict[str, Any]: #type:ignore
+
+    def get(self, key: str, default: Any = None) -> Any:
+        """Return the value for the given key, or a default value if the key does not exist."""
+        return self.data.get(key, default)
+
+    def __dict__(self) -> Dict[str, Any]:  # type:ignore
         return self.data
 
 
 class UploadedFile:
-
     """
     An uploaded file included as part of the request data.
     """
@@ -750,12 +754,17 @@ class UploadedFile:
         )
 
 
-class FormData(ImmutableMultiDict[str, typing.Union[UploadedFile, str]]):
-
+class FormData(
+    MultiDict[str, typing.Union[UploadedFile, str, Sequence[Any]]]  # type:ignore
+):  # type:ignore
     def __init__(
         self,
-        *args: typing.Union[FormData , typing.Mapping[str, typing.Union[str , UploadedFile]] , list[tuple[str, typing.Union[str , UploadedFile]]]],
-        **kwargs: typing.Union[str , UploadedFile],
+        *args: typing.Union[
+            FormData,
+            typing.Mapping[str, typing.Union[str, UploadedFile]],
+            list[tuple[str, typing.Union[str, UploadedFile]]],
+        ],
+        **kwargs: typing.Union[str, UploadedFile],
     ) -> None:
         super().__init__(*args, **kwargs)
 
@@ -763,3 +772,21 @@ class FormData(ImmutableMultiDict[str, typing.Union[UploadedFile, str]]):
         for _, value in self.multi_items():
             if isinstance(value, UploadedFile):
                 await value.close()
+
+    def get(
+        self, key: str, default: typing.Any = None
+    ) -> typing.Union[UploadedFile, str, None]:
+        """
+        Get a value from the form data by key.
+
+        Args:
+            key: The key to look up
+            default: Value to return if key is not found
+
+        Returns:
+            The value if found, or the default
+        """
+        try:
+            return self[key]
+        except KeyError:
+            return default
