@@ -1,5 +1,6 @@
 from nexios.http import Request, Response
 from nexios.routing import Router
+from nexios.templating import render
 
 index_router = Router()
 
@@ -7,4 +8,4 @@ index_router = Router()
 @index_router.get("/")
 async def index(request: Request, response: Response):
     """Index route for the application."""
-    return response.json({"message": "Welcome to the Nexios application!"})
+    return await render("index.html")
